# dyscord

A simplistic implementation of the discord API.

[![Testing Main](https://github.com/isbe.house/dyscord/actions/workflows/python-testing.yml/badge.svg?branch=main)](https://github.com/isbe.house/dyscord/actions/workflows/python-testing.yml) [![Testing Dev](https://github.com/isbe.house/dyscord/actions/workflows/python-testing.yml/badge.svg?branch=dev)](https://github.com/isbe.house/dyscord/actions/workflows/python-testing.yml) [![Downloads](https://static.pepy.tech/personalized-badge/dyscord?period=total&units=international_system&left_color=black&right_color=brightgreen&left_text=Downloads)](https://pepy.tech/project/dyscord)

# Current Status

Very much an active WIP. The API to this library is not at all locked down. Users can expect aggressive changes to the API until we hit v1.0.0

# Documentation

We are following [Google Style](https://sphinxcontrib-napoleon.readthedocs.io/en/latest/example_google.html) docstring patterns.

Actual published documentation is still very much a WIP.

# Community

Come talk on the [Dyscord subreddit](https://www.reddit.com/r/dyscord/), or the [Dyscord discord](https://discord.gg/Q9NFzgZx)!

# Changelog

See the [Changelog](docs/changelog.md).